
//	New or modified code (C)2004 Jeffrey Bakker aka EvilJess <evil@damnclan.com>
//	Existing code for Unreal  Tournament 2004 Copyright  2004 Epic Games, Inc.


//	AkimBin - Akimbo meets BinSlayer
//	Copyright (C) 2004 Jeffrey Bakker

//	This library is free software; you can redistribute it and/or
//	modify it under the terms of the GNU Lesser General Public
//	License as published by the Free Software Foundation; either
//	version 2.1 of the License, or (at your option) any later version.

//	This library is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//	Lesser General Public License for more details.

//	You should have received a copy of the GNU Lesser General Public
//	License along with this library; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


class BinSlayer extends AssaultRifle;

#exec TEXTURE IMPORT NAME=EvilIcon FILE=textures\EvilIcon.pcx  GROUP=Skins
#exec TEXTURE IMPORT NAME=Scope	FILE=textures\Scope.pcx GROUP=Skins

var transient float LastFOV;
var() bool bZooming; // is it currently zooming?

// Zoom SSR code //////////////////////////////////////////////////////////////
simulated function ClientWeaponThrown()
{
    if( Instigator != None && Instigator.Controller.IsA( 'PlayerController' ) )
        PlayerController(Instigator.Controller).EndZoom();
    Super.ClientWeaponThrown();
}

simulated function ClientStartFire(int mode)
{
    if (mode == 1)
    {
        FireMode[mode].bIsFiring = true;
        if( Instigator.Controller.IsA( 'PlayerController' ) )
            PlayerController(Instigator.Controller).ToggleZoom();
    }
    else
    {
        Super.ClientStartFire(mode);
    }
}

simulated function ClientStopFire(int mode)
{
    if (mode == 1)
    {
        FireMode[mode].bIsFiring = false;
        if( Instigator.Controller.IsA( 'PlayerController' ) )
            PlayerController(Instigator.Controller).StopZoom();
    }
    else
    {
        Super.ClientStopFire(mode);
    }
}

simulated function BringUp(optional Weapon PrevWeapon)
{
	if ( PlayerController(Instigator.Controller) != None )
		LastFOV = PlayerController(Instigator.Controller).DesiredFOV;
	Super.BringUp();
}

simulated function bool PutDown()
{
	if( Instigator.Controller.IsA( 'PlayerController' ) )
		PlayerController(Instigator.Controller).EndZoom();
	if ( Super.PutDown() )
	{
		GotoState('');
		return true;
	}
	return false;
}

// compensate for bright fog
simulated function SetZoomBlendColor(Canvas c)
{
    local Byte    val;
    local Color   clr;
    local Color   fog;

    clr.R = 255;
    clr.G = 255;
    clr.B = 255;
    clr.A = 255;

    if( Instigator.Region.Zone.bDistanceFog )
    {
        fog = Instigator.Region.Zone.DistanceFogColor;
        val = 0;
        val = Max( val, fog.R);
        val = Max( val, fog.G);
        val = Max( val, fog.B);

        if( val > 128 )
        {
            val -= 128;
            clr.R -= val;
            clr.G -= val;
            clr.B -= val;
        }
    }
    c.DrawColor = clr;
}
///////////////////////////////////////////////////////////////////////////////

// Modified AssaultRifle code /////////////////////////////////////////////////
function AttachToPawn(Pawn P)
{
	local name BoneName;

	if ( ThirdPersonActor == None )
	{
		ThirdPersonActor = Spawn(AttachmentClass,Owner);
		InventoryAttachment(ThirdPersonActor).InitFor(self);
	}
	BoneName = P.GetWeaponBoneFor(self);
	if ( BoneName == '' )
	{
		ThirdPersonActor.SetLocation(P.Location);
		ThirdPersonActor.SetBase(P);
	}
	else
		P.AttachToBone(ThirdPersonActor,BoneName);

	if ( bDualMode )
	{
		BoneName = P.GetOffHandBoneFor(self);
		if ( BoneName == '' )
			return;
		if ( OffhandActor == None )
		{
			OffhandActor = AssaultAttachment(Spawn(AttachmentClass,Owner));
			OffhandActor.InitFor(self);
			OffHandActor.SetDrawScale(0.160000);
		}
		P.AttachToBone(OffhandActor,BoneName);
		if ( OffhandActor.AttachmentBone == '' )
			OffhandActor.Destroy();
		else
		{
			ThirdPersonActor.SetDrawScale(0.160000);	// sniper model size
			OffhandActor.SetDrawScale(0.160000);		// sniper model size
			OffhandActor.bDualGun = true;
			OffhandActor.TwinGun = AssaultAttachment(ThirdPersonActor);
			if ( Mesh == OldMesh )
			{
			    OffhandActor.SetRelativeRotation(rot(0,32768,0));
			    OffhandActor.SetRelativeLocation(vect(20,-10,-5));
			}
			else
			{
			    OffhandActor.SetRelativeRotation(rot(0,0,32768));
			    OffhandActor.SetRelativeLocation(vect(40,-3,-7));
			}
			AssaultAttachment(ThirdPersonActor).TwinGun = OffhandActor;
		}
	}
}

function bool HandlePickupQuery( pickup Item )
{
	if ( class == Item.InventoryType )
	{
		if ( bDualMode )
			return Super.HandlePickupQuery(Item);
		bDualMode = true;
		if ( Instigator.Weapon == self )
		{
			PlayOwnedSound(SelectSound, SLOT_Interact,,,,, false);
			AttachToPawn(Instigator);
		}
		if (Level.GRI.WeaponBerserk > 1.0)
			CheckSuperBerserk();
		else	FireMode[0].FireRate = FireMode[0].Default.FireRate *  0.65;

		if (xPawn(Instigator) != None && xPawn(Instigator).bBerserk)
			StartBerserk();

		return false;
	}

	if ( Inventory == None )
		return false;

	return Inventory.HandlePickupQuery(Item);
}

simulated function DetachFromPawn(Pawn P)
{
	bFireLeft = false;
	Super.DetachFromPawn(P);

	if ( OffhandActor != None )
	{
		OffhandActor.Destroy();
		OffhandActor = None;
	}
}

function byte BestMode()
{
	return 0;
}

simulated function float ChargeBar()
{
	return 1;
}

simulated function DrawWeaponInfo(Canvas Canvas)		{}
simulated function NewDrawWeaponInfo(Canvas Canvas, float YPos)	{}
///////////////////////////////////////////////////////////////////////////////

simulated event RenderOverlays( Canvas Canvas )
{
	local PlayerController PCtrl;
	local float Scale;

	PCtrl = PlayerController(Instigator.Controller);

	if ( LastFOV > PCtrl.DesiredFOV )
	{
		PlaySound(Sound'WeaponSounds.LightningGun.LightningZoomIn', SLOT_Misc,,,,,false);

	}
	else if ( LastFOV < PlayerController(Instigator.Controller).DesiredFOV )
	{
		PlaySound(Sound'WeaponSounds.LightningGun.LightningZoomOut', SLOT_Misc,,,,,false);
	}

	LastFOV = PCtrl.DesiredFOV;

	if ( PCtrl.DesiredFOV == PCtrl.DefaultFOV)
	{
		Super.RenderOverlays(Canvas);
		bZooming=false;

		PCtrl.MyHud.bCrosshairShow = true;
		PCtrl.MyHud.bShowWeaponInfo = True;
		PCtrl.MyHud.bShowPersonalInfo = True;
		PCtrl.MyHud.bShowPoints = True;
		PCtrl.MyHud.bShowWeaponBar = False;
	}
	else
	{
		SetZoomBlendColor(Canvas);

		PCtrl.MyHud.bCrosshairShow = False;
		PCtrl.MyHud.bShowWeaponInfo = False;
		PCtrl.MyHud.bShowPersonalInfo = False;
		PCtrl.MyHud.bShowPoints = False;
		PCtrl.MyHud.bShowWeaponBar = False;

		Canvas.Style = ERenderStyle.STY_Translucent;

		Canvas.SetPos(0,0);
		Canvas.DrawTile( FinalBlend'XGameShaders.ZoomFX.ModuNoise', Canvas.SizeX, Canvas.SizeY, 0.0, 0.0, 512, 512 );

		Scale = Canvas.ClipX/640 * 1.0; //1.5
		Canvas.SetPos(0.5 * Canvas.ClipX - 64 * Scale, 0.5 * Canvas.ClipY - 64 * Scale );
		Canvas.DrawIcon(Texture'Scope', Scale*0.50);

		Canvas.SetPos(0.5 * Canvas.ClipX + 64 * Scale, 0.5 * Canvas.ClipY + 96 * Scale);
		Canvas.DrawColor.R = 255;
		Canvas.DrawColor.G = 0;
		Canvas.DrawColor.B = 0;

		Scale = PCtrl.DefaultFOV/PCtrl.DesiredFOV;

		Canvas.Font = PCtrl.MyHud.LargerFontThan(Canvas.Font);
		Canvas.bNoSmooth = false;

		Canvas.SetPos(0.5 * Canvas.ClipX + 98 * Scale, 0.5 * Canvas.ClipY + 130 * Scale);
		Canvas.DrawText(""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2));
		Canvas.SetPos(0.5 * Canvas.ClipX + 90 * Scale, 0.5 * Canvas.ClipY + 118 * Scale);
		Canvas.DrawText(""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2)$""$Rand(2));

		Canvas.SetPos(102,120);
		Canvas.DrawText("(C)2004 EvilJess");
		Canvas.SetPos(102,140);
		Canvas.DrawText("www.damnclan.com");
		Canvas.SetPos(102,160);
		Canvas.DrawText(scale$"x Zoom Precision");

		Canvas.SetPos(-16,88);
		Canvas.DrawIcon(Texture'EvilIcon', 1);

		Canvas.SetPos(15,64);
		Canvas.Font = PCtrl.MyHud.LargerFontThan(Canvas.Font);
		Canvas.DrawText(ItemName);

		Canvas.SetPos(12,62);
		Canvas.DrawText(ItemName);

		bZooming = true;
	}
}

defaultproperties
{
	ItemName="AkimBinSlayer"
	Description="AkimBin Beta. Akimbo meets BinSlayer.||By 3v1LJess aka Jeffrey Bakker|http://binslayer.damnclan.com"
	FireModeClass(0)=Class'AkimBinBeta.AkimBinFire'
	FireModeClass(1)=Class'XWeapons.SniperZoom'
	bShowChargingBar=False

	AttachmentClass=Class'AkimBinBeta.AkimbinAttachment'

	BringUpTime=0.1
	PutDownTime=0.1

	SelectSound=Sound'NewWeaponSounds.WeaponsLocker_01'
	SelectForce="NewSniperLoad"

	Mesh=SkeletalMesh'SniperAnims.SniperRifle_1st'
	DrawScale=0.480000

	EffectOffset=(X=100.000000,Y=28.000000,Z=-19.000000)
	DisplayFOV=60.000000
	SmallViewOffset=(X=36.900002,Y=10.000000,Z=-14.000000)
	CenteredOffsetY=0.000000
	CenteredYaw=-500
	PlayerViewOffset=(X=27.700001,Y=5.300000,Z=-10.600000)
	PlayerViewPivot=(Yaw=16384)

	Skins(0)=Shader'BarrensArchitecture-Scion.Environ.My_Environ_BlueFlag'
	Skins(1)=Shader'BarrensArchitecture-Scion.Environ.My_Environ_BlueFlag'
	HighDetailOverlay=None //Combiner'UT2004Weapons.WeaponSpecMap2'

	PickupClass=Class'AkimBinBeta.AkimBinPickup'
	InventoryGroup=9
	GroupOffset=1
}
